@@ -2,22 +2,30 @@ import tempfile
 from pathlib import Path
 from typing import List
 
+from .types import StoryBuild, StoryMention
+
 try:
     from moviepy.editor import CompositeVideoClip, ImageClip, TextClip, VideoFileClip
 except ImportError:
-    raise Exception('Please install moviepy==1.0.3 and retry')
+    raise Exception("Please install moviepy==1.0.3 and retry")
 
-from .types import StoryBuild, StoryMention
 
 
 class StoryBuilder:
     """
     Helpers for Story building
     """
+
     width = 720
     height = 1280
 
-    def __init__(self, path: Path, caption: str = "", mentions: List[StoryMention] = [], bgpath: Path = None):
+    def __init__(
+        self,
+        path: Path,
+        caption: str = "",
+        mentions: List[StoryMention] = [],
+        bgpath: Path = None,
+    ):
         """
         Initialization function
 
@@ -60,8 +68,7 @@ class StoryBuilder:
         clips = []
         # Background
         if self.bgpath:
-            assert self.bgpath.exists(),\
-                f'Wrong path to background {self.bgpath}'
+            assert self.bgpath.exists(), f"Wrong path to background {self.bgpath}"
             background = ImageClip(str(self.bgpath))
             clips.append(background)
         # Media clip
@@ -73,18 +80,27 @@ class StoryBuilder:
         clips.append(media_clip)
         mention = self.mentions[0] if self.mentions else None
         # Text clip
-        caption = "@%s" % mention.user.username if mention.user.username else self.caption
+        caption = (
+            "@%s" % mention.user.username if mention.user.username else self.caption
+        )
         text_clip = TextClip(
-            caption, color="white", font="Arial",
-            kerning=-1, fontsize=100, method="label"
+            caption,
+            color="white",
+            font="Arial",
+            kerning=-1,
+            fontsize=100,
+            method="label",
         )
         text_clip_left = (self.width - 600) / 2
         text_clip_top = clip_top + clip.size[1] + 50
         offset = (text_clip_top + text_clip.size[1]) - self.height
         if offset > 0:
             text_clip_top -= offset + 90
-        text_clip = text_clip.resize(width=600).set_position(
-            (text_clip_left, text_clip_top)).fadein(3)
+        text_clip = (
+            text_clip.resize(width=600)
+            .set_position((text_clip_left, text_clip_top))
+            .fadein(3)
+        )
         clips.append(text_clip)
         # Mentions
         mentions = []
@@ -97,11 +113,12 @@ class StoryBuilder:
         duration = max_duration
         if max_duration and clip.duration and max_duration > clip.duration:
             duration = clip.duration
-        destination = tempfile.mktemp('.mp4')
-        CompositeVideoClip(clips, size=(self.width, self.height))\
-            .set_fps(24)\
-            .set_duration(duration)\
-            .write_videofile(destination, codec='libx264', audio=True, audio_codec='aac')
+        destination = tempfile.mktemp(".mp4")
+        CompositeVideoClip(clips, size=(self.width, self.height)).set_fps(
+            24
+        ).set_duration(duration).write_videofile(
+            destination, codec="libx264", audio=True, audio_codec="aac"
+        )
         return StoryBuild(mentions=mentions, path=destination)
 
     def video(self, max_duration: int = 0):
